From 2cb1563f63386b35a69e460051aa9b4a2851d104 Mon Sep 17 00:00:00 2001
From: ftimme <ft@falkotimme.com>
Date: Wed, 30 May 2012 07:30:44 -0400
Subject: [PATCH] - Added (clickable) placeholders to client messaging function. - Added check so that the client password isn't inserted into the message (for security reasons).

---
 install/install.php |   19 ++++++++++++++++---
 1 files changed, 16 insertions(+), 3 deletions(-)

diff --git a/install/install.php b/install/install.php
index a31efbc..3f86370 100644
--- a/install/install.php
+++ b/install/install.php
@@ -102,8 +102,12 @@
 //** Detect the installed applications
 $inst->find_installed_apps();
 
 //** Select the language
 $conf['language'] = $inst->simple_query('Select language', array('en','de'), 'en');
+
+exec('date +%Z', $tmp_out);
+$conf['timezone'] = $tmp_out[0];
+unset($tmp_out);
 
 //** Select installation mode
 $install_mode = $inst->simple_query('Installation mode', array('standard','expert'), 'standard');
@@ -112,7 +116,7 @@
 //** Get the hostname
 $tmp_out = array();
 exec('hostname -f', $tmp_out);
-$conf['hostname'] = $inst->free_query('Full qualified hostname (FQDN) of the server, eg server1.domain.tld ', $tmp_out[0]);
+$conf['hostname'] = $inst->free_query('Full qualified hostname (FQDN) of the server, eg server1.domain.tld ', @$tmp_out[0]);
 unset($tmp_out);
 
 // Check if the mysql functions are loaded in PHP
@@ -126,6 +130,12 @@
 	$tmp_mysql_server_admin_password = $inst->free_query('MySQL root password', $conf['mysql']['admin_password']);
 	$tmp_mysql_server_database = $inst->free_query('MySQL database to create', $conf['mysql']['database']);
 	$tmp_mysql_server_charset = $inst->free_query('MySQL charset', $conf['mysql']['charset']);
+	
+	if($install_mode == 'expert') {
+		swriteln("The next two questions are about the internal ISPConfig database user and password.\nIt is recommended to accept the defaults which are 'ispconfig' as username and a random password.\nIf you use a different password, use only numbers and chars for the password.\n");
+		$conf['mysql']['ispconfig_user'] = $inst->free_query('ISPConfig mysql database username', $conf['mysql']['ispconfig_user']);
+		$conf['mysql']['ispconfig_password'] = $inst->free_query('ISPConfig mysql database password', $conf['mysql']['ispconfig_password']);
+	}
 	
 	//* Initialize the MySQL server connection
 	if(@mysql_connect($tmp_mysql_server_host, $tmp_mysql_server_admin_user, $tmp_mysql_server_admin_password)) {
@@ -274,7 +284,10 @@
 	swriteln('Installing ISPConfig');
 	
 	//** Customize the port ISPConfig runs on
-	$conf['apache']['vhost_port'] = $inst->free_query('ISPConfig Port', '8080');
+	$ispconfig_vhost_port = $inst->free_query('ISPConfig Port', '8080');
+	if($conf['apache']['installed'] == true) $conf['apache']['vhost_port']  = $ispconfig_vhost_port;
+	if($conf['nginx']['installed'] == true) $conf['nginx']['vhost_port']  = $ispconfig_vhost_port;
+	unset($ispconfig_vhost_port);
 
 	if(strtolower($inst->simple_query('Do you want a secure (SSL) connection to the ISPConfig web interface',array('y','n'),'y')) == 'y') {
 	  $inst->make_ispconfig_ssl_cert();
@@ -102,8 +102,12 @@
 $inst->find_installed_apps();
 
-//** Select the language
+//** Select the language and set default timezone
 $conf['language'] = $inst->simple_query('Select language', array('en','de'), 'en');

--
Gitblit v1.9.1